function p = signif(a,b)
% p = signif(a,b)
%    Calculate statistical significance of results from different 
%    classification algorithms.
%    <a> is a binary vector of whether algorithm A got each trial 
%    right or wrong; <b> is the corresponding vector for algorithm
%    B on paired examples.
%    p returns the significance level.
% 2007-07-06 Dan Ellis dpwe@ee.columbia.edu
% $Header: $

if nargin == 2
  % Calculate right/wrong matrix
  rwm = [sum(a & b) sum(a & ~b); sum(~a & b) sum(~a & ~b)];
else
  % assume rwm passed in
  rwm = a;
end
  
disp(sprintf('A / B   R     W'));
disp(sprintf('  R %5d %5d',rwm(1,1),rwm(1,2)));
disp(sprintf('  W %5d %5d',rwm(2,1),rwm(2,2)));

% statistics
N = sum(rwm(:));
pa = sum(rwm(1,:))/N;
pb = sum(rwm(:,1))/N;

disp(['Algo A: acc = ',sprintf('%.2f%%',100*pa)]);
disp(['Algo B: acc = ',sprintf('%.2f%%',100*pb)]);
disp(['A better on ',sprintf('%.2f%%',100*rwm(1,2)/N)]);
disp(['B better on ',sprintf('%.2f%%',100*rwm(2,1)/N)]);


nab = rwm(2,1);
ndiff = rwm(2,1)+rwm(1,2);

% binomial test, gauss approx
diffp = abs(pa-pb);
sigma = sqrt((pa*(1-pa) + pb*(1-pb))/N);
z = diffp/sigma;

pbin = pofz_1sided(z);
disp(['1 sided binomial significance = ',num2str(pbin)]);

% McNemar test, gauss approx
% diagonals are binomial distrib with mean = 1/2
% from Gillick & Cox
z = (abs(nab - ndiff/2) - 0.5)/sqrt(ndiff/4);
pmcn = pofz_1sided(z);
disp(['1 sided McNemar significance = ',num2str(pmcn)]);

if nargout > 0
  p = pmcn;
end


function p = pofz_1sided(z)
% binomial test - 1 sided
%z = erfinv((1-p)*2-1)*sqrt(2);
p = 1 - (erf(z/sqrt(2)) + 1)/2;

function p = pofz_2sided(z)
% 2 sided
%z = erfinv((1-p))*sqrt(2)
p = 1 - (erf(z/sqrt(2)));