function lhoods = test_track(file,models,ntsamp,dims,beatlevel)
% lhoods = test_track(file,models,ntsamp,dims)
%   Read features from <file>, evaluate likelihood under each of
%   the items in the <models> array, return likelihoods as a
%   vector.
% 2007-07-04 Dan Ellis dpwe@ee.columbia.edu

if nargin < 3; ntsamp = 1000; end
if nargin < 4; dims = []; end
if nargin < 5; twin = 1; end
if nargin < 6; beatlevel = 0; end

if beatlevel
  D = load(file);
  d = D.M';
else
  d = readhtk(file);
end

if isempty(dims); dims = 1:size(d,2); end

% choose random time samples
% ri will consist of ntsamp random indices (with replacement) at least 
% one quarter of the dataset length away from the ends
guard = round(size(d,1)/4); % how far to stay away from ends
ri = guard + ceil((size(d,1)-2*guard)*rand(1,ntsamp));
  
% Evaluate likelihood of this data under every model
for model = 1:length(models)
  lhoods(model) = model_match(models(model), d(ri,dims));
end
  
