function model = train_model(trnset,ngmm,nsamp,dims,beatlevel)
% model = train_model(trnset,ngmm,nsamp,dims,beatlevel)
%   trnset is a list (cell array) of data files defining a class
%   ngmm is the number of gaussian components (default 20), 
%   nsamp is the number of randomly-selcted frames to train on.
%   dims is a vector indexing which dimensions of the data to use (empty->all)
%   model is the model we return with fields mean, sigma, prior, nmix
% 2007-04-03 Dan Ellis dpwe@ee.columbia.edu  artist ID demo system

% How many gaussian components?
if nargin < 2;  ngmm = 20; end
% Randomly sample how many data points?
if nargin < 3;  nsamp = 2000; end
% Which dimensions to use in the data?  Default to all
if nargin < 4;  dims = []; end
if nargin < 5;  beatlevel = 0; end

data = [];

% Load all the data
for i = 1:length(trnset)
  if beatlevel
    D = load(trnset{i});
    d = D.M';
  else
    d = readhtk(trnset{i});
  end
  % only add the middle part of each file into the pool
  % ri will consist of ntsamp random indices (with replacement) at least 
  % <guard> samples away from end, where guard is larger of 1000 or one
  % quarter of the dataset length
  guard = round(size(d,1)/4); % how far to stay away from ends
  ri = guard + ceil((size(d,1)-2*guard)*rand(1,nsamp));
  data = [data; d(ri,:)];
end

% If no dimensions explicitly selected, use them all
if isempty(dims)
  dims = 1:size(data,2);
end

% remove unwanted dimensions
data = data(:,dims);

model = model_train_data(data, ngmm);
